import { Button, PageHeader, Space, Table } from "ant-design-vue";
import { defineComponent, onMounted, reactive } from "vue";

import loading from "@/components/Provider/Loading";
import { useArticle } from "@/modules/admin";
import { CategoryItem } from "@/typings/asset";
import { object } from "vue-types";
import WangEditor from "../../components/WangEditor";
import * as dayjs from "dayjs";
import ListEditModal from "./ListEditModal";
import Modal from "@/components/Provider/Modal";

export default defineComponent({
  props: {
    data: object<CategoryItem>(),
  },
  setup(props) {
    const data: any = props.data || {};
    const artStore = useArticle();
    const state = reactive({
      data: {} as any,
    });

    onMounted(() => {
      initList();
    });

    const initList = async () => {
      loading.show("");
      artStore.listController.state.query = JSON.stringify({ cid: data._id });
      await artStore.listController.loadPage(1);
      //   const item = artStore.listController.state.list[0] || {};
      //   if (item._id) {
      //     const detRes = await artStore.getArticleDetail(item);
      //     if (detRes) {
      //       state.data = detRes;
      //     }
      //   }
      loading.hidden();
    };
    const columns = [
      {
        title: "名称",
        dataIndex: "title",
      },
      {
        title: "创建时间",
        dataIndex: "createTime",
        customRender({ record }: any) {
          return dayjs(record.createTime).format("YYYY-MM-DD");
        },
      },
      {
        title: "操作",
        customRender: ({ record }: any) => {
          return (
            <Space>
              <Button
                type="link"
                onClick={() => {
                  editItem(record);
                  console.log(record);
                }}
              >
                编辑
              </Button>
              <Button
                danger
                type="link"
                onClick={() => {
                  console.log(record);
                }}
              >
                删除
              </Button>
            </Space>
          );
        },
      },
    ];
    const editItem = async (item?: any) => {
      const itemData = Modal.show(<ListEditModal />, {
        title: item._id ? `编辑${data?.name}` : `添加${data?.name}`,
        fullscreen: true,
      });
    };
    const submit = () => {
      const subData = { ...state.data };
      if (!subData._id) {
        subData.title = data?.name;
        subData.cid = data._id;
      }
      artStore.addOrUpdateArticle(subData);
    };

    return () => {
      return (
        <div>
          <PageHeader title={data?.name}>
            {{
              extra: () => {
                return (
                  <Button
                    type="primary"
                    onClick={() => {
                      editItem({});
                    }}
                  >
                    添加{data?.name}
                  </Button>
                );
              },
            }}
          </PageHeader>
          <Table
            bordered
            size="small"
            pagination={{
              size: "small",
              showSizeChanger: false,
              pageSize: artStore.listController.state.size,
              total: artStore.listController.state.total,
              onChange: (v) => artStore.listController.loadPage(v),
            }}
            columns={columns}
            dataSource={artStore.listController.state.list}
          ></Table>
        </div>
      );
    };
  },
});
